package com.aoc.psisclient.base;

import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.core.config.Configurator;
import org.apache.logging.log4j.core.config.DefaultConfiguration;

import x0CoreSchema.oasisNamesTcDss1.OptionalOutputsDocument.OptionalOutputs;
import x0CoreSchema.oasisNamesTcDss1.ResultDocument.Result;
import x0CoreSchema.oasisNamesTcDss1.VerifyResponseDocument;

import com.aoc.psisclient.config.PsisClientFactoryConfigurator;


public class AbstractSample {
	protected Logger log;

	protected static String PDF_PROFILE = "urn:oasis:names:tc:dss:1.0:profiles:DSS_PDF";
	protected static String XML_PROFILE = "urn:oasis:names:tc:dss:1.0:profiles:XSS";

	protected static final String DIGEST_ALGORITHM_SHA1 = "http://www.w3.org/2000/09/xmldsig#sha1";

	protected static final String UPDATE_TYPE_XADES_A = "urn:oasis:names:tc:dss:1.0:profiles:XAdES:forms:ES-A";
	
	protected static final String MIME_TYPE_APPLICATION_PDF = "application/pdf";

	protected static final String CADES_SIGNATURE_TYPE = "http://uri.etsi.org/01733/v1.6.3#";
	
	protected static final String PADES_LTV_TYPE = "urn:oasis:names:tc:dss:1.0:profiles:XAdES:forms:ES-LTV";

	
	protected PsisClientFactory factory;

	public AbstractSample(){
        
        Configurator.initialize(new DefaultConfiguration());
        Configurator.setRootLevel(Level.DEBUG);

		this.log = LogManager.getLogger(AbstractSample.class);
		this.factory = new PsisClientFactory();
		this.factory.setConfigurator(new PsisClientFactoryConfigurator());
		
		// Otherwise client can not be created:
		// [Fatal Error] xmldsig-core-schema.xsd:10:5: External DTD: Failed to read external DTD 'XMLSchema.dtd', 
		// because 'http' access is not allowed due to restriction set by the accessExternalDTD property.
		System.setProperty("javax.xml.accessExternalDTD", "all");
				
	}

	protected boolean isRessultWellFormed(VerifyResponseDocument response){
		boolean ok = response!=null && response.getVerifyResponse()!=null && response.getVerifyResponse().getResult()!=null;
		return ok;
	}

	protected void showMinorMajorRessult(VerifyResponseDocument response){
		Result result = response.getVerifyResponse().getResult();
		this.log.info("Minor: "+result.getResultMinor()+"\nMajor: "+result.getResultMajor());
	}

	protected void showOptionalOutputs(VerifyResponseDocument response){
		OptionalOutputs optionalOutputs = response.getVerifyResponse().getOptionalOutputs();
		if(optionalOutputs!=null){
			this.log.info("Optional Outputs:\n"+optionalOutputs.toString());
		}else{
			this.log.info("No optional Outputs");
		}
	}

}
