package com.aoc.psisclient.samples;

import java.io.File;
import java.io.IOException;

import org.apache.commons.io.FileUtils;
import org.apache.xmlbeans.XmlException;

import x0CoreSchema.oasisNamesTcDss1.Base64SignatureDocument.Base64Signature;
import x0CoreSchema.oasisNamesTcDss1.OptionalInputsDocument.OptionalInputs;
import x0CoreSchema.oasisNamesTcDss1.VerifyRequestDocument;
import x0CoreSchema.oasisNamesTcDss1.VerifyRequestDocument.VerifyRequest;
import x0CoreSchema.oasisNamesTcDss1.VerifyResponseDocument;

import com.aoc.psisclient.base.AbstractSample;

public class CadesSignatureValidationSample extends AbstractSample {

	public static void main(String[] args){
		try {
			CadesSignatureValidationSample validation = new CadesSignatureValidationSample();
			File fileSignatureDetached = new File("src\\signatures\\cades.p7b");
			File fileDocDetached = new File("src\\signatures\\doc.txt");
			validation.checkDetachedSignatureAndShowRessult(fileSignatureDetached, fileDocDetached);
		}catch(Exception e){
			System.out.print(e);
		}
	}

	public void checkDetachedSignatureAndShowRessult(File fileSignature, File docDetached) throws XmlException, IOException {
		VerifyResponseDocument response = verifyCadesSignature(fileSignature, docDetached);
		if(isRessultWellFormed(response)){
			showMinorMajorRessult(response);
			showOptionalOutputs(response);
		}
	}

	public VerifyResponseDocument verifyCadesSignature(File fileSignature, File docDetached) throws XmlException, IOException {
		this.log.debug("Start validation "+XML_PROFILE);
		VerifyRequest request = VerifyRequest.Factory.newInstance();
		request.setProfile(XML_PROFILE);

		this.log.debug("Loading detached document");
		byte [] cadesDocDetached = FileUtils.readFileToByteArray(docDetached);
		request.addNewInputDocuments().addNewDocument().addNewBase64Data().setByteArrayValue(cadesDocDetached);

		this.log.debug("Loading CADES signature");
		byte [] cadesSignature = FileUtils.readFileToByteArray(fileSignature);
		Base64Signature base64Signature = request.addNewSignatureObject().addNewBase64Signature();
		base64Signature.setByteArrayValue(cadesSignature);
		base64Signature.setType(CADES_SIGNATURE_TYPE);


		this.log.debug("Adding optionalInput UPDATE signature to "+UPDATE_TYPE_XADES_A);
		OptionalInputs optionalInput = request.addNewOptionalInputs();
		optionalInput.addNewReturnUpdatedSignature().setType(UPDATE_TYPE_XADES_A);
		request.setOptionalInputs(optionalInput);

		this.log.debug("Send request XML verification");
		VerifyRequestDocument verifyRequest = VerifyRequestDocument.Factory.newInstance();
		verifyRequest.setVerifyRequest(request);
		VerifyResponseDocument response = this.factory.getDssPort().verify(verifyRequest);
		return response;
	}
}
